==> levseq-1.0.2-py3-none-any.whl: levseq/__init__.py <==
###############################################################################
#                                                                             #
#    This program is free software: you can redistribute it and/or modify     #
#    it under the terms of the GNU General Public License as published by     #
#    the Free Software Foundation, either version 3 of the License, or        #
#    (at your option) any later version.                                      #
#                                                                             #
#    This program is distributed in the hope that it will be useful,          #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of           #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            #
#    GNU General Public License for more details.                             #
#                                                                             #
#    You should have received a copy of the GNU General Public License        #
#    along with this program. If not, see <http://www.gnu.org/licenses/>.     #
#                                                                             #
###############################################################################

__title__ = 'levseq'
__description__ = 'LevSeq nanopore sequencing'
__url__ = 'https://github.com/fhalab/levseq/'
__version__ = '1.0.2'
__author__ = 'Yueming Long, Emreay Gursoy, Ariane Mora'
__author_email__ = 'ylong@caltech.edu'
__license__ = 'GPL3'

from levseq.globals import *
from levseq.variantcaller import *
from levseq.visualization import *
from levseq.interface import *
from levseq.cmd import *
from levseq.utils import *
from levseq.simulation import *
from levseq.user import *

==> levseq-1.1.1-py3-none-any.whl: levseq/__init__.py <==
###############################################################################
#                                                                             #
#    This program is free software: you can redistribute it and/or modify     #
#    it under the terms of the GNU General Public License as published by     #
#    the Free Software Foundation, either version 3 of the License, or        #
#    (at your option) any later version.                                      #
#                                                                             #
#    This program is distributed in the hope that it will be useful,          #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of           #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            #
#    GNU General Public License for more details.                             #
#                                                                             #
#    You should have received a copy of the GNU General Public License        #
#    along with this program. If not, see <http://www.gnu.org/licenses/>.     #
#                                                                             #
###############################################################################

__title__ = 'levseq'
__description__ = 'LevSeq nanopore sequencing'
__url__ = 'https://github.com/fhalab/levseq/'
__version__ = '1.1.1'
__author__ = 'Yueming Long, Emreay Gursoy, Ariane Mora, Francesca-Zhoufan Li'
__author_email__ = 'ylong@caltech.edu'
__license__ = 'GPL3'

from levseq.globals import *
from levseq.variantcaller import *
from levseq.visualization import *
from levseq.interface import *
from levseq.cmd import *
from levseq.utils import *
from levseq.simulation import *
from levseq.user import *
